/*
This dofile reproduces the findings from the presentation by Jorge Rodriguez Meza
for the World Bank Enterprise Symposium on Global Business Environment and Firm Productivity
June 5, 2025

For questions or suggestions, please contact: enterprisesurveys@worldbank.org
or the relevant authors mentioned below
*/

*============================================================================
* This section is written by Mohammad Amin <mamin@worldbank.org> and Norma Gomez <ngomez1@worldbank.org>
* with edits from Nona Karalashvili <nkaralashvili@worldbank.org>  
*============================================================================

**# Setting up data
*==============================================================================================================================================================
* Step 1: Create an account to access our Data Portal on this link https://login.enterprisesurveys.org/content/sites/financeandprivatesector/en/signin.html
* Step 2: Download the following files from the Data Portal and put them all in the same folder with this dofile:
*	      File 1: New_Comprehensive_May_5_2025.dta
*         File 2: ES-Indicators-Database-Global-Methodology_May_5_2025.dta
*         File 3: Firm Level TFP Estimates and Factor Ratios_May_5_2025.dta
*==============================================================================================================================================================

** Step 3: Setting up directories
clear  all
set more off

global  raw_combined "New_Comprehensive_May_5_2025.dta" // downloaded from Step 2 above
global 	indicators   "ES-Indicators-Database-Global-Methodology_May_5_2025.dta" // downloaded from Step 2 above
global 	tfp_dta	     "Firm Level TFP Estimates and Factor Ratios_May_5_2025.dta" // downloaded from Step 2 above
global  tfp_hk       "Firm Level TFP HK.dta" // included with the dofile
global 	inc_class    "income_classification.dta" // included with the dofile
global  wdi          "WDI_4-28-2025.dta" // included with the dofile
global  gdp_file     "GDP_per capita_PPP_current international_2025.dta" // included with the dofile

** Step 4: Putting the data together
clear
clear matrix 
use "$raw_combined"
	gen year = substr(country,-4,4)
	destring year, replace
	drop if year < 2023 & country != "Bangladesh2022"& country != "Iraq2022"& country != "Madagascar2022"& country != "Pakistan2022"& country != "Timor-Leste2021"
	drop year 
gen data_103=1 // indicator for the data in the 103 countries
	
merge 1:1 idstd using  "$indicators" 
keep if data_103==1 
drop _merge //checked that all the previous merge is all OK.

gen original_year=year //to preserve the original year in the data

drop income
merge 1:1 idstd using "$tfp_dta" 
keep if data_103==1 
drop _merge //checked that all the previous merge is all OK.

* Merging the World Bank income classification data:
sort wbcode year
merge wbcode year using "$inc_class" 
drop _merge 
keep if data_103==1 
label var income_WB "Income group from the income classification data" 

* Merging GDP per capita data:
drop year
gen year=original_year-1 //to be used for merging with 1 year lagged values of GDP 

sort wbcode year
merge wbcode year using "$wdi", keep(gdp gdp1) //WDI data is missing for Taiwan, China
drop _merge
keep if data_103==1 
rename gdp1 gdp2 //two year lagged (from year_original defined above) gdp data 
rename gdp gdp1 //one year lagged (from year_original defined above) gdp per capita 

label var gdp1 "GDP per capita, PPP (constant 2021 Int'l $), 1 year lagged" // Data on gdp1 is missing for some countries 
label var gdp2 "GDP per capita, PPP (constant 2021 Int'l $), 2 years lagged"  //missing for two countries.

*Generating the controls:
gen ln_size=ln(size_num)
gen ln_age=ln(car1)
gen ln_exp=ln(wk8) 
gen multi=cond(a7==1,1,0) if a7==1|a7==2 
 
label var gdp1 "GDP per capita (1 year lagged, PPP, 2021 Int'l $)"
label var gdp2 "GDP per capita (2 year lagged, PPP, 2021 Int'l $)"
label var multi "Multi establishment Y:1 N:0 (a7 variable)" // based on a7 
label var ln_size "Number of workers (log of size_num)" 
label var ln_age "Age of firm (log of car1)"
label var ln_exp "Manager experience (log of wk8)"
drop year 
rename original_year year

*Normalized wieghts: 
by country, sort: egen wtsum=sum(wt) 
gen wt1=wt/wtsum 
drop wtsum 
label var wt1 "Sampling weights normalized at the country-level"

save "combined_data_WBES_103.dta", replace

**# Estimations on Labor Productivity

*============================================================================
* This section is written by Hibret Belete Maemir <hmaemir@worldbank.org>
* with edits from Nona Karalashvili <nkaralashvili@worldbank.org>  
*============================================================================

use "combined_data_WBES_103.dta", clear 

*============================================================================
** Definition of variables  
*============================================================================

g lprYL = log(d2_gdp09/size_num)   // sales per worker  
lab var lprYL "Labor Productivity (sales per worker)"   

g VA = d2_gdp09 - n2e_gdp09
replace VA =. if VA<0  // code negative value-added as missing

g lprVAL = log(VA/size_num)  // value-added per worker  
lab var lprVAL "Labor Productivity (value-added per worker)"

g capital_intensity = log(n7a_gdp09/size_num)
lab var capital_intensity "Capital Intensity"

g ln_wl = log(n2a_gdp09/size_num)

encode wbcode, gen(iso3)
gen ln_GDP_pc_PPP_ci = ln(gdp1)

svyset idstd [pw=wt1], strata(strata) singleunit(scaled)

g isic2 = isic_v4  
drop income 

levelsof income_WB
g income = 1 if income_WB == "Low Income"
replace income = 2  if income_WB == "Lower Middle Income"
replace income = 3  if income_WB == "Upper Middle Income"
replace income = 4  if income_WB == "High Income"

label define income 1 "Low Income"  2 "Lower Middle Income" 3 "Upper Middle Income" 4 "High Income"
label values  income income

g sme = inlist(size,1,2)&size!=.  
		tab size sme, miss

preserve  
	bys country : egen sum_sales = total(d2_gdp09*wt1)
	bys country  isic2: egen sum_sales_isic = total(d2_gdp09*wt1)
	g sales_share = sum_sales_isic/ sum_sales

	bys wbcode isic2: keep if _n==1
	keep wbcode isic2 sales_share

	tempfile sales_share
	save `sales_share', replace
restore  

preserve
	bys wbcode year isic2: egen double W_s  = total(wt1)
	bys wbcode year isic2: egen double Wy_s = total(wt1*lprYL)
	gen double mu_s = Wy_s / W_s                                // sector mean

	bys wbcode year : egen double W_sum  = total(wt1)          
	bys wbcode year: egen double Wy_sum = total(wt1*lprYL)   
	gen double mu_c = Wy_sum / W_sum                           // overall mean
				
	collapse ///
			(first) mu_c              = mu_c   mu_s = mu_s    ///
			(sum) N_firms            = lprYL  /// 
			(mean)  mean_lprYL        = lprYL   /// weighted mean
			(p25)   p25_lprYL         = lprYL   /// weighted 25th pct
			(p75)   p75_lprYL         = lprYL   /// weighted 75th pct
			(iqr)   iqr_lprYL         = lprYL   /// p75 – p25
			[pw = wt1], ///
			by(isic2 wbcode country_official year region income_WB)
			

	merge 1:1 wbcode isic2 using `sales_share',  keep(match master) nogen

	bys wbcode: egen iqr_lpr = total(iqr_lprYL*sales_share)
	bys wbcode: egen mean_lpr = total(mean_lprYL*sales_share)

	keep wbcode iqr_lpr mean_lpr year region income_WB country_official
	bys wbcode year: keep if _n==1 

	merge 1:1  wbcode year using "$gdp_file", keep(3)

	gen ln_GDP_pc_PPP_ci = ln(_GDP_pc_PPP_ci)
	drop if inlist(wbcode, "MDG", "SLE")

**# figure 1. labor productivity across economies
		
		tw   (scatter mean_lpr ln_GDP_pc_PPP_ci if wbcode != "ISL" ) ///
		(lowess  mean_lpr ln_GDP_pc_PPP_ci, bw(.8)  lcolor(purple) lwidth(medthick) lpattern(solid)), ///
			  xlabel(, angle(45)) xsize(1.3) ysize(1)  ytitle("") ///
			  xtitle("") ///
			  xlabel(6.907755279 "1,000" 7.60090246 "2,000" 8.29404964 "4,000" 8.987196821 "8,000" 9.680344001 "16,000" 10.37349118 "32,000" 11.06663836 "64,000" 11.75978554 "128,000" 12.45293272 "256,000",  format(%9.0fc) angle(45)) ///
			  ylabel(6.907755279 "1,000" 7.60090246 "2,000" 8.29404964 "4,000" 8.987196821 "8,000" 9.680344001 "16,000" 10.37349118 "32,000" 11.06663836 "64,000" 11.75978554 "128,000" 12.45293272 "256,000",  format(%9.0fc)) legend(off)
		graph export "productivity_overall.png", as(png)  replace	  
			  	
				

**# figure 2. labor productivity across economies, with some economies highlighted
			  
	tw   (scatter mean_lpr ln_GDP_pc_PPP_ci if wbcode != "ISL" ) ///
		(scatter mean_lpr ln_GDP_pc_PPP_ci if wbcode=="TCD", mlabel(country_official ) mlabsize(small)) ///
		(scatter mean_lpr ln_GDP_pc_PPP_ci if wbcode=="USA", mlabel(country_official ) mlabsize(small)) ///
		(scatter mean_lpr ln_GDP_pc_PPP_ci if wbcode=="NPL", mlabel(country_official ) mlabsize(small)) ///
		(scatter mean_lpr ln_GDP_pc_PPP_ci if wbcode=="COL", mlabel(country_official ) mlabsize(small)) ///
		(lowess  mean_lpr ln_GDP_pc_PPP_ci, bw(.8)  lcolor(purple) lwidth(medthick) lpattern(solid)), ///
			  xtitle("") 	  ///
			  xlabel(, angle(45)) xsize(1.3) ysize(1)  ytitle("") ///
			  xlabel(6.907755279 "1,000" 7.60090246 "2,000" 8.29404964 "4,000" 8.987196821 "8,000" 9.680344001 "16,000" 10.37349118 "32,000" 11.06663836 "64,000" 11.75978554 "128,000" 12.45293272 "256,000",  format(%9.0fc) angle(45)) ///
			  ylabel(6.907755279 "1,000" 7.60090246 "2,000" 8.29404964 "4,000" 8.987196821 "8,000" 9.680344001 "16,000" 10.37349118 "32,000" 11.06663836 "64,000" 11.75978554 "128,000" 12.45293272 "256,000",  format(%9.0fc)) legend(off)
		graph export "productivity_overall_CountryCodes.png", as(png)  replace		
		
**# figure 3. gap in labor productivity across economies
* title("{bf:Ratio of labor productivity of the top 25% with bottom 25% of firms}", size(medium) position(11)) 	

	twoway (scatter iqr_lpr ln_GDP_pc_PPP_ci if wbcode != "COD")   ///
		(scatter iqr_lpr ln_GDP_pc_PPP_ci if wbcode=="TCD", mlabel(country_official )  mlabsize(small)) ///
		(scatter iqr_lpr ln_GDP_pc_PPP_ci if wbcode=="USA", mlabel(country_official )  mlabsize(small)) ///
		(scatter iqr_lpr ln_GDP_pc_PPP_ci if wbcode=="NPL", mlabel(country_official )  mlabsize(small)) ///
		(scatter iqr_lpr ln_GDP_pc_PPP_ci if wbcode=="COL", mlabel(country_official )  mlabsize(small)) ///
			(lowess  iqr_lpr ln_GDP_pc_PPP_ci, bw(.8) lcolor(purple) lwidth(medthick) lpattern(solid)), ///
			  xtitle("") 	  ///
			  xlabel(, angle(45)) xsize(1.25) ysize(1)  ytitle("") ///
			  xlabel(6.907755279 "1,000" 7.60090246 "2,000" 8.29404964 "4,000" 8.987196821 "8,000" 9.680344001 "16,000" 10.37349118 "32,000" 11.06663836 "64,000" 11.75978554 "128,000" 12.45293272 "256,000",  format(%9.0fc) angle(45)) ///
			  ylabel(0 "1" 0.69314718 "2" 1.3862944 "4" 2.079441542 "8" 2.772588722 "16" 3.465735903 "32",  format(%9.0fc)) ///
			    legend(off) 
		graph export "GAP_productivity_overall_regions_CountryCodes.png", as(png)  replace			  

**# data for figure 4, average gap labor productivity by income level
			collapse (mean) iqr_lpr ,by(income_WB)
			replace iqr_lpr = exp(iqr_lpr)
			label var iqr_lpr  "Ratio of labor productivity of the top 25% with bottom 25% of firms"
			label var income_WB "Income"
			replace income_WB = subinstr(income_WB, " Income", "",.)
			export excel "labor prody gap.xlsx", firstrow(varlabels) replace	 
restore

preserve
	bys country sector_MS: egen sum_sales = total(d2_gdp09*wt1)
	bys country  isic2 sector_MS: egen sum_sales_isic = total(d2_gdp09*wt1)
	g sales_share = sum_sales_isic/ sum_sales

	bys wbcode isic2 sector_MS: keep if _n==1
	keep wbcode isic2 sector_MS sales_share
	
	tempfile sales_shares_sector_M
	save `sales_shares_sector_M'
restore

preserve
	bys wbcode year isic2 sector_MS: egen double W_s  = total(wt1)
	bys wbcode year isic2 sector_MS: egen double Wy_s = total(wt1*lprYL)
	gen double mu_s = Wy_s / W_s                                // sector mean

	bys wbcode year sector_MS : egen double W_sum  = total(wt1)          
	bys wbcode year sector_MS: egen double Wy_sum = total(wt1*lprYL)   
	gen double mu_c = Wy_sum / W_sum                           // overall mean
		
	replace sector_MS = "Manufacturing" if inrange(isic2,10,33)
	replace sector_MS = "Services" if inrange(isic2,41,95)
	tab isic2 sector_MS, m
		
		collapse ///
				(first) mu_c              = mu_c   mu_s = mu_s    ///
				(sum) N_firms            = lprYL  /// 
				(mean)  mean_lprYL        = lprYL   /// weighted mean
				(p25)   p25_lprYL         = lprYL   /// weighted 25th pct
				(p75)   p75_lprYL         = lprYL   /// weighted 75th pct
				(iqr)   iqr_lprYL         = lprYL   /// p75 – p25
				[pw = wt1], ///
				by(isic2 wbcode country_official year region income_WB sector_MS)


		merge 1:1 wbcode isic2 sector_MS using  `sales_shares_sector_M',  keep(match master) nogen

		bys wbcode sector_MS: egen iqr_lpr = total(iqr_lprYL*sales_share)
		bys wbcode sector_MS: egen mean_lpr = total(mean_lprYL*sales_share)

		keep wbcode iqr_lpr mean_lpr  year region income_WB sector_MS
		bys wbcode year sector_MS: keep if _n==1 

		merge m:1  wbcode year using "$gdp_file", keep(3)

		gen ln_GDP_pc_PPP_ci = ln(_GDP_pc_PPP_ci)
		drop if inlist(wbcode, "MDG", "SLE")

**# data for figure 5, average gap labor productivity by sector and income level
	
	collapse (mean) iqr_lpr ,by(income_WB sector_MS)
	replace iqr_lpr = exp(iqr_lpr)
	reshape wide iqr_lpr, i(income_WB) j(sector_MS) string
	label var iqr_lprManufacturing  "Manufacturing"
	label var iqr_lprServices "Services"
	label var income_WB "Income"
	replace income_WB = subinstr(income_WB, " Income", "",.)
	order income_WB iqr_lprManufacturing iqr_lprServices
	export excel "labor prody gap_by sector.xlsx", firstrow(varlabels) replace	 
restore

**# Estimations on Total Factor Productivity
*============================================================================
* This section is written by Nona Karalashvili <nkaralashvili@worldbank.org>  
*============================================================================
	
preserve  

	keep if isic == 10

	collapse (mean)  sector_mean_tfprYKLM        = tfprYKLM   /// 
			(mean)  sector_mean_tfprVAKL        = tfprVAKL   /// 
			(mean) gdp2 ///
			[pw = wt1], ///
			by( wbcode year income_WB country_official)
			
	merge 1:1  wbcode year using "$gdp_file", keep(3)

	gen ln_GDP_pc_PPP_ci = ln(_GDP_pc_PPP_ci)
	drop if inlist(wbcode, "MDG", "SLE")

**# figure 6, total factor productivity for food manufacturers
*		  title("{bf:Average total factor productivity among food manufacturers}", size(medium) position(11)) ///

  tw   (scatter sector_mean_tfprYKLM ln_GDP_pc_PPP_ci if wbcode != "SLV") ///
	(scatter sector_mean_tfprYKLM ln_GDP_pc_PPP_ci if wbcode=="TCD", mlabel(country_official )) ///
	(scatter sector_mean_tfprYKLM ln_GDP_pc_PPP_ci if wbcode=="USA", mlabel(country_official )) ///
	(scatter sector_mean_tfprYKLM ln_GDP_pc_PPP_ci if wbcode=="NPL", mlabel(country_official )) ///
	(scatter sector_mean_tfprYKLM ln_GDP_pc_PPP_ci if wbcode=="COL", mlabel(country_official )) ///
		(lfit  sector_mean_tfprYKLM ln_GDP_pc_PPP_ci, lcolor(purple) lwidth(medthick) lpattern(solid)), ///
		  xtitle("") 	  ///
		  xlabel(, angle(45)) xsize(1.5) ysize(1)  ytitle("") xlabel(6.907755279 "1,000" 7.60090246 "2,000" 8.29404964 "4,000" 8.987196821 "8,000" 9.680344001 "16,000" 10.37349118 "32,000" 11.06663836 "64,000" 11.75978554 "128,000" 12.45293272 "256,000",  format(%9.0fc) angle(45)) legend(off)
	graph export "YKLM_productivity_FOOD_no_regions_CountryCodes.png", as(png)  replace
	
restore

*============================================================================
* This section is written by Hibret Belete Maemir <hmaemir@worldbank.org>
* with edits from Nona Karalashvili <nkaralashvili@worldbank.org>  
* and Norma Gomez <ngomez1@worldbank.org>  
*============================================================================
preserve
	use "combined_data_WBES_103", clear 
		keep wbcode income_WB country_official
		duplicates drop
	tempfile income_WB
	save `income_WB'

	use "$tfp_hk", clear

	bys isic2 country year: egen iqr_TFPR = iqr(lnTFPR)
	collapse (firstnm)  iqr_TFPR theta M , by(isic2 year wbcode)

	foreach x in   iqr_TFPR {
	replace `x'=theta*`x'
	}

	collapse (sum) iqr_TFPR (sum) M   theta, by(year wbcode) 
			
	bys wbcode (year): keep if _n==_N

	merge  1:1 year wbcode using "$gdp_file", keep(match master) nogen

	g  ln_GDP_pc_PPP_ci = ln(_GDP_pc_PPP_ci)
					
	drop if M <20  
	
	merge m:1 wbcode using `income_WB', nogen keep(3)

**# data for figure 7, total factor productivity gap across income levels

	collapse (mean) iqr_TFPR ,by(income_WB)
	replace iqr_TFPR = exp(iqr_TFPR)
	label var iqr_TFPR  "Ratio of total factor productivity of the top 25% with bottom 25% of firms"
	label var income_WB "Income"
	replace income_WB = subinstr(income_WB, " Income", "",.)
	export excel "tfp gap_by income.xlsx", firstrow(varlabels) replace	 
restore
	
ssc install reghdfe
ssc install ftools

preserve  
	recode income (3=2) (4=2), gen(income_low)
	tab income_low income, m

	reghdfe ln_size c.lprYL#i.income ln_age ln_exp multi ownership  [aw = wt1], ///
		abs(wbcode isic2) vce(cluster wbcode)		
		
	estimates store resultsize

**# figure 8, size elasticity of labor productivity
	coefplot resultsize, mlabposition(1) mlabgap(*2) /// 
		recast(bar) ci(off) barwidt(0.3)    ///
		keep("1.income#c.lprYL" "2.income#c.lprYL" ///
         "3.income#c.lprYL" "4.income#c.lprYL") ///
		rename( ///
			"1.income#c.lprYL" = "Low" ///
			"2.income#c.lprYL" = "Lower-Middle" ///
			"3.income#c.lprYL" = "Upper-Middle" ///
			"4.income#c.lprYL" = "High" ///
		) ///
		  base vert ///
		  ylabel(0 "0" 0.01 "0.1" 0.02 "0.2" 0.03 "0.3" 0.04 "0.4" 0.05 "0.5" 0.06 "0.6") ///
		 title("{bf:% change in jobs due to 10% change in productivity}", size(medium) position(11)) /// 
		ytitle("") ///
		xtitle("{bf: Income Group}") legend(off) saving(emp_prod.gph, replace)
		
	graph export "size_elasticity_prody_by_income.png", as(png)  replace		
restore

*============================================================================
* This section is written by David C. Francis <dfrancis@worldbank.org>  
* with edits by Norma Gomez <ngomez1@worldbank.org>  
*============================================================================
	//Set preliminaries 
	use "combined_data_WBES_103.dta"  , clear
	
//Merge in wb income group that varies by year
	merge m:1 wbcode year using "$inc_class", update replace
	assert _m!=1
	drop if _m==2
	drop _m
	
//Svyset the data for rescaled weights 
	svyset idstd [pw=wt1], singleunit(scaled) strata(strata)
	
//Generate age cohorts
	gen age = 1 if inrange(car1,0,4)
	replace age =2 if inrange(car1,5,9)
	replace age =3 if inrange(car1,10,14)
	replace age =4 if inrange(car1,15,19)
	replace age =5 if inrange(car1,20,24)
	replace age =6 if inrange(car1,25,29)
	replace age =7 if inrange(car1,30,34)

//Size at start-up
	gen size_startup = 1 if inrange(b6,1,19)
	replace size_startup = 2 if inrange(b6,20,99)
	replace size_startup = 3 if inrange(b6,100,9999999999)
	
	tab size_startup if !missing(b6), g(sz_start)
	
	*svy: mean sz_start2 ,over(income_num)
	
	//Lifecycle growth 
	gen growth_life_firm = l1/b6 if l1>=0 & b6>=0
	gen ln_growth=ln(growth_life_firm)
	gen growth_life_firm_annual = growth_life_firm/car1
	gen ln_growth_an = ln(growth_life_firm_annual)

	preserve 
	collapse (p1) p1_gr=ln_growth p1_gr_an=ln_growth_an (p5) p5_gr=ln_growth p5_gr_an=ln_growth_an (p95) p95_gr=ln_growth p95_gr_an=ln_growth_an (p99) p99_gr=ln_growth p99_gr_an=ln_growth_an [pw=wt],by(country)
	tempfile trim
	save `trim'
	restore 
	
	merge country using `trim', sort uniqusing
	
	//Manually winsorized lifecycle 
	gen growth_life_firm_win1 = growth_life_firm
	replace growth_life_firm_win1 = p1_gr  if growth_life_firm<=p1_gr
	replace growth_life_firm_win1 = p99_gr if growth_life_firm>=p99_gr & !missing(growth_life_firm)
	gen growth_life_outlier1 = growth_life_firm_win1!=growth_life_firm
		
	gen growth_life_firm_win5 = growth_life_firm
	replace growth_life_firm_win5 = growth_life_firm  if ln_growth<=p5_gr
	replace growth_life_firm_win5 = growth_life_firm  if ln_growth>=p95_gr & !missing(growth_life_firm)
	gen growth_life_outlier5 = growth_life_firm_win5!=growth_life_firm
	
	
	gen growth_life_firm_ann_win5 = growth_life_firm
	replace growth_life_firm_ann_win5 = .  if ln_growth_an<=p5_gr_an
	replace growth_life_firm_ann_win5 = . if  ln_growth_an>=p95_gr_an & !missing(ln_growth_an)
	gen growth_life_outlier5_an = growth_life_firm_ann_win5!=growth_life_firm
	
	//Encode income group 
	encode income_WB, g(income_num)
	
	//Industry dummies 
	gen _d1a2_v4=d1a2_v4/100
	tostring _d1a2_v4, g(_temp) force
	gen _2digit = substr(_temp,1,2)
	destring _2digit, replace
	
	
	//Table: mean start-up size (using the same restrictions as the lower analysis)
	svy: mean b6 if growth_life_outlier5_an!=1 & b6>=0 ,over(income_num)
	svy: mean b6 if growth_life_outlier5_an!=1 & b6>=0 ,over(income_num size_startup)
	
	preserve 
	collapse (mean) mn_startup=b6 (median) med_startup=b6 if growth_life_outlier5_an!=1 & b6>=0 [pw=wt], by(country income_num)
	collapse (mean) *_startup, by(income_num)
	list 
	restore 
	
	
	/////////////////////////// ANALYSIS FOR FIGURES ///////////////////////////

	cap drop beta ul ll cohort income_grouping
	gen beta =.
	gen ul =.
	gen ll =.
	gen cohort =.
	gen income_grouping =.
		
	svy: reg growth_life_firm i.age##i.income_num if growth_life_outlier5_an!=1  , coeflegend
	
	//Start the counter 
	local place=1
	
	//Baseline 
	nlcom _b[_cons] /_b[_cons]
		
		matrix table=r(table)
		local b=table[1,1]
		local u=table[6,1]
		local l=table[5,1]
		replace beta=`b' if _n==`place'
		replace cohort=1 if _n==`place'
		replace income_grouping=1 if _n==`place'
		replace beta=`b' if _n==`place'
		replace ul=`u' if _n==`place'
		replace ll=`l' if _n==`place'
		local place=`place'+1
	
	//Now, loop through cohorts 
	forval c=2/7 {
		
		nlcom (_b[`c'.age]+_b[_cons]) / (_b[_cons])
		
		matrix table=r(table)
		local b=table[1,1]
		local u=table[6,1]
		local l=table[5,1]
		replace beta=`b' if _n==`place'
		replace cohort=`c' if _n==`place'
		replace income_grouping=1 if _n==`place'
		replace beta=`b' if _n==`place'
		replace ul=`u' if _n==`place'
		replace ll=`l' if _n==`place'
		local place=`place'+1
	}
		
	//Repeat the same process, over income and cohort 
	forval i=2/4 {
		forval c=1/7 {
			if `c'==1 {
				nlcom (_b[_cons]+ _b[`i'.income_num]) /(_b[_cons]+ _b[`i'.income_num])		
			}
			if `c'>1 {
				nlcom (_b[`c'.age]+_b[_cons] + _b[`i'.income_num] + _b[`c'.age#`i'.income_num]) /(_b[_cons]+ _b[`i'.income_num])	
			}
			matrix table=r(table)
			local b=table[1,1]
			local u=table[6,1]
			local l=table[5,1]
			replace beta=`b' if _n==`place'
			replace cohort=`c' if _n==`place'
			replace income_grouping=`i' if _n==`place'
			replace beta=`b' if _n==`place'
			replace ul=`u' if _n==`place'
			replace ll=`l' if _n==`place'
			local place=`place'+1
		}
	}
	
	//GET WEIGHTS FOR SIZE OF DOTS BASED ON AGE
	tab age, g(age_dum)
	gen age_prop=.
	forval age = 1/7 {
		svy: mean age_dum`age',over(income_num)
		matrix table=r(table)
		matrix list table
		forval gr = 1/4 {
			replace age_prop=table[1,`gr'] if cohort==`age' & income_grouping==`gr'
		}
	}


	
	//THIS IS THE ACTUAL FIGURE
**# figure 9, lifetime growth profile
	twoway  scatter beta cohort if income_grouping==1 , c(l) lcolor(blue)    || /*
	*/		scatter beta cohort if income_grouping==2 , c(l) lcolor(orange)  || /*
	*/		scatter beta cohort if income_grouping==3 , c(l) lcolor(green) 	|| /*
	*/		scatter beta cohort if income_grouping==4 , c(l) lcolor(red)		   /*
	*/      xlab(1 "1-4" 2 "5-9" 3 "10-14" 4 "15-19" 5 "20-24" 6 "25-29" 7 "30-34" 8" ", notick nogrid labsize(medlarge)) legend(off) /*
	*/		text(3.5 7.5 "High Income", color(blue) size(medlarge)) text(3.0 7.6 "Upper Middle" "Income", color(red) size(medlarge)) /*
	*/      text(2.15 7.35 "Low Income", color(orange) size(medlarge)) text(2.5 7.4 "Lower Middle" "Income", color(green) size(medlarge)) /*
	*/      title("{bf: Size relative to when they started operations}", pos(11)) ytitle(" ") /*
	*/ 		ylab(, labsize(large))  xsize(12.17) ysize(5.94) ylab( 1 "1x" 1.5 " " 2 "2x" 2.5 " " 3 "3x" 3.5 "3.5x" 4 "4x" /*4.5 " " 5 "5x" 5.5 " " 6 "6x" 6.5 " " 7 "7x"*/) xtitle("{bf: Age cohort of the firms (years)}", size(medlarge)) saving("Global_lifecycle growth", replace )
	
	graph export "Global_lifecycle growth.jpg", replace 

*============================================================================
* This section is written by Nona Karalashvili <nkaralashvili@worldbank.org>  
*============================================================================
us "combined_data_WBES_103.dta", clear 

preserve
	collapse (mean) wk1 wk2 gdp2 (first) country income_WB region [pw=wt], by(year wbcode country_official)
	
	gen loggdp  = log(gdp2 )

	reg wk1 loggdp, robust
	cap drop wk1_predict
	predict wk1_predict
	
	gen wbcode4 = country_official if  wbcode=="TCD" | wbcode=="USA"| wbcode=="NPL"|wbcode=="COL"
	
**# figure 10, formal training
	twoway (scatter wk1 gdp2 if region==1,mlabel(wbcode4 ))  (scatter wk1 gdp2 if region==2,mlabel(wbcode4 )) (scatter wk1 gdp2 if region==3,mlabel(wbcode4 ))  (scatter wk1 gdp2 if region==4,mlabel(wbcode4 ))  (scatter wk1 gdp2 if region==5,mlabel(wbcode4 ))  (scatter wk1 gdp2 if region==6,mlabel(wbcode4 ))  (scatter wk1 gdp2 if region==7,mlabel(wbcode4 )) ///
					(line wk1_predict gdp2 ), xscale(log)  xtitle("{bf:GDP per capita, PPP (constant 2021 international $)}") title("{bf:% firms offering formal training}", size(medium) position(11)) xlabel(1000 2000 4000 8000 16000 32000 64000 128000,  format(%9.0fc) angle(45)) legend(order(2 "East Asia & Pacific" 3 "Europe & Central Asia" 4 "Latin America & the Caribbean" 5 "Middle East & North Africa" 7 "North America" 6 "South Asia" 1 "Sub-Saharan Africa") position(6) cols(4)) xsize(12.17) ysize(5.94) ytitle("") name(wk1, replace) 
	graph export "wk1_vs_gdp.png", as("png") replace
restore
	
*============================================================================
* This section is written by Phoebe W. Ishak <pishak@worldbank.org>
* with edits from Nona Karalashvili <nkaralashvili@worldbank.org>  
*============================================================================

preserve
	collapse in16 region gdp2 [w=wt], by(country wbcode country_official)

	gen loggdp  = log(gdp2 )
	reg in16 loggdp, robust
	predict in16_predict

**# figure 11, electricity across economies
	twoway (scatter in16 gdp2 if region==1)  (scatter in16 gdp2 if region==2) (scatter in16 gdp2 if region==3)  (scatter in16 gdp2 if region==4)  (scatter in16 gdp2 if region==5)  (scatter in16 gdp2 if region==6) (scatter in16 gdp2 if region==7)  (line in16_predict gdp2 ), xscale(log)  xtitle("{bf:GDP per capita, PPP (constant 2021 international $)}") title("{bf:Share of firms experiencing electricity outages}", size(medium) position(11)) xlabel(1000 2000 4000 8000 16000 32000 64000 128000,  format(%9.0fc) angle(45)) legend(order(2 "East Asia & Pacific" 3 "Europe & Central Asia" 4 "Latin America & the Caribbean" 5 "Middle East & North Africa" 7 "North America" 6 "South Asia" 1 "Sub-Saharan Africa") position(6) cols(4)) xsize(12.17) ysize(5.94) ylabel(0 20 40 60 80 100) ytitle("") 
	graph export "in16_vs_gdp_WithoutLables.png", as(png)  replace

**# figure 12, electricity across economies, with some country labels
	graph twoway (scatter in16 gdp2 if region==1)  (scatter in16 gdp2 if region==2) (scatter in16 gdp2 if region==3)  (scatter in16 gdp2 if region==4)  (scatter in16 gdp2 if region==5)  (scatter in16 gdp2 if region==6) (scatter in16 gdp2 if region==7)  (line in16_predict gdp2 ) (scatter in16 gdp2 if wbcode=="MDG", mlabel(country_official ) mcolor(stc1) mlabcolor(stc1) ) (scatter in16 gdp2 if wbcode=="POL", mlabel(country_official) mcolor(stc3) mlabcolor(stc3)  mlabposition(9) ) (scatter in16 gdp2 if wbcode=="IDN", mlabel(country_official) mcolor(stc2) mlabcolor(stc2) ) (scatter in16 gdp2 if wbcode=="MEX", mlabel(country_official) mcolor(stc4) mlabcolor(stc4)) (scatter in16 gdp2 if wbcode=="JOR", mlabel(country_official) mlabposition(9) mcolor(stc5) mlabcolor(stc5)) (scatter in16 gdp2 if wbcode=="USA", mlabel(country_official) mcolor(stc7) mlabcolor(stc7)) (scatter in16 gdp2 if wbcode=="PAK", mlabel(country_official ) mcolor(stc6) mlabcolor(stc6)), xscale(log)  xtitle("{bf:GDP per capita, PPP (constant 2021 international $)}") title("{bf:Share of firms experiencing electricity outages}", size(medium) position(11)) xlabel(1000 2000 4000 8000 16000 32000 64000 128000 ,  format(%9.0fc) angle(45))  legend(order(2 "East Asia & Pacific" 3 "Europe & Central Asia" 4 "Latin America & the Caribbean" 5 "Middle East & North Africa" 7 "North America" 6 "South Asia" 1 "Sub-Saharan Africa") position(6) cols(4)) xsize(12.17) ysize(5.94) ylabel(0 20 40 60 80 100) ytitle("") 
	graph export "in16_vs_gdp_withLabels.png", as(png)  replace
restore
 
//Everything everywhere all at once:
preserve
	tempfile treatx
	collapse in16 region gdp2 [w=wt], by(country wbcode)
	rename in16 in16_X
	gen loggdp  = log(gdp2 )
	reg in16_X loggdp, robust
	predict in16_predict
	save `treatx'
restore

preserve
	egen subnational= group(a3a countryx)
	collapse in16 gdp2 [w=wt], by(country wbcode subnational country_official)
	bysort wbcode: egen wbcode1 = max(in16)
	gen in16x = round(in16, 0.0001)
	gen wbcode1x = round(wbcode1, 0.0001)
	gen wbcodex = country_official if wbcode1x==in16x
	gen loggdp  = log(gdp2 )
	reg in16 loggdp, robust
	predict in16_predictx

	merge m:m country wbcode using `treatx'

	bysort country wbcode: gen order=_n
	replace in16_X=. if order > 1

**# figure 13, electricity across economies, with some country labels, with disaggregation by regions
	twoway (scatter in16_X gdp2 if region==1, mlabcolor(stc2))  (scatter in16_X gdp2 if region==2, mlabcolor(stc3)) (scatter in16_X gdp2 if region==3, mlabcolor(stc4))  (scatter in16_X gdp2 if region==4, mlabcolor(stc5))  (scatter in16_X gdp2 if region==5, mlabcolor(stc6))  (scatter in16_X gdp2 if region==6, mlabcolor(stc7)) (scatter in16_X gdp2 if region==7, mlabcolor(stc8)) (connected in16 gdp2 if wbcode=="POL", mlabel(wbcodex) mlabposition(3) mcolor(stc3) mlabcolor(stc3)  lcolor(stc3)) (connected in16 gdp2 if wbcode=="IDN", mlabel(wbcodex) mcolor(stc2) mlabcolor(stc2)  lcolor(stc2)) (connected in16 gdp2 if wbcode=="USA", mlabel(wbcodex) mcolor(stc7) mlabcolor(stc7)  lcolor(stc7)) (connected in16 gdp2 if wbcode=="MEX", mlabel(wbcodex) mcolor(stc4) mlabcolor(stc4)  lcolor(stc4))  (connected in16 gdp2 if wbcode=="JOR", mlabel(wbcodex) mlabposition(3) mcolor(stc5) mlabcolor(stc5)  lcolor(stc5)) (connected in16 gdp2 if wbcode=="PAK", mlabel(wbcodex ) mcolor(stc6) mlabcolor(stc6)  lcolor(stc6)) (connected in16 gdp2 if wbcode=="MDG", mlabel(wbcodex) mcolor(stc1) mlabcolor(stc1)  lcolor(stc1)) (line in16_predict gdp2 ), xscale(log)  xtitle("{bf:GDP per capita, PPP (constant 2021 international $)}") title("{bf:Share of firms experiencing electricity outages - disaggregated by region}", size(medium) position(11)) xlabel(1000 2000 4000 8000 16000 32000 64000 128000,  format(%9.0fc) angle(45)) legend(order(2 "East Asia & Pacific" 3 "Europe & Central Asia" 4 "Latin America & the Caribbean" 5 "Middle East & North Africa" 7 "North America"  6 "South Asia" 1 "Sub-Saharan Africa") position(6) cols(4)) xsize(12.17) ysize(5.94) ylabel(0 20 40 60 80 100) ytitle("") 
	graph export "in16_vs_gdp_DISwithBubles.png", as(png)  replace
restore

*============================================================================
* This section is written by Gemechu Ayana Aga <gayanaaga@worldbank.org> and Filip Jolevski <fjolevski@worldbank.org>
* with edits from Nona Karalashvili <nkaralashvili@worldbank.org>  
*============================================================================
	
preserve
	collapse (mean) graft3 corr1 corr10 corr9 corr8 corr6 corr7 [pw=wt], by(country income_WB wbcode)
	collapse (mean) graft3 corr1 corr10 corr9 corr8 corr6 corr7 , by(income_WB)

	label var graft3 "Bribery Incidence"
	label var corr1 "Tax officials"
	label var corr10 "Operating license"
	label var corr9 "Import license"
	label var corr8 "Construction permit"
	label var corr6 "Electrical connection"
	label var corr7 "Water connection"

	label var income_WB "Income"

	order income_WB corr1 corr10 corr9 corr6 corr7 corr8 graft3

**# data for figures 14 and 15, corruption by income level
	export excel using "corruption_by_income_group.xlsx", firstrow(varlabels) replace
restore

*============================================================================
* This section is written by Solomiya Shpak <sshpak@worldbank.org>;
* Davide Salvatore Mare <dmare@worldbank.org>
* with edits from Nona Karalashvili <nkaralashvili@worldbank.org>  
*============================================================================

	gen fin23_24 = 100 if fin23 == 100 | fin24 == 100
	replace fin23_24 = 0 if fin23 == 0 & fin24 == 0
	tab fin23_24 fin25, m
	
**# data for figure 16, access to finance by income level
preserve 
	collapse (mean) fin23_24 gdp2 (first) country income_WB region [pw=wt], by(year wbcode)
	collapse (mean) fin23_24, by(income_WB)
	
	label var fin23_24 "Share of credit constrained firms"
	label var income_WB "Income"
	export excel using "fin23_24_by_income_group.xlsx", firstrow(varlabels) replace
restore

**# data for figure 17, access to finance by size and income level
preserve
	collapse (mean) fin23_24 gdp2 (first) country income_WB region [pw=wt], by(year size wbcode)
	reshape wide fin23_24, i(gdp2 country income_WB region year wbcode) j(size)

	collapse (mean) fin23_241 fin23_243 , by(income_WB)
	
	replace income_WB = subinstr(income_WB, " Income", "",.)
	label var fin23_241 "Small"
	label var fin23_243 "Large"
	label var income_WB "Income"
	export excel "finance gap_by income.xlsx", firstrow(varlabels) replace	 	
restore 

*============================================================================
* This section is written by Nona Karalashvili <nkaralashvili@worldbank.org>  
*============================================================================
**# data for figure 18, R & D by income group
preserve		
	collapse (mean) t10 (first) country income_WB region [pw=wt], by(year wbcode)		
	drop if wbcode == "CAF"
	collapse (mean) t10, by(income_WB)
	replace income_WB = subinstr(income_WB, " Income", "",.)
	label var t10 "Percent of firms that spend on R&D in the last fiscal years"
	export excel "R&D_by income.xlsx", firstrow(varlabels) replace	 			
restore